@@ -432,6 +432,46 @@ export const hasProvisionings = () => {
   })
 }
 
+export const hasRadiusEaps = () => {
+  return store.dispatch('config/getRadiusEaps').then(response => {
+    return (response.length > 0)
+  }).catch(() => {
+    return true
+  })
+}
+
+export const hasRadiusFasts = () => {
+  return store.dispatch('config/getRadiusFasts').then(response => {
+    return (response.length > 0)
+  }).catch(() => {
+    return true
+  })
+}
+
+export const hasRadiusOcsps = () => {
+  return store.dispatch('config/getRadiusOcsps').then(response => {
+    return (response.length > 0)
+  }).catch(() => {
+    return true
+  })
+}
+
+export const hasRadiusSsls = () => {
+  return store.dispatch('config/getRadiusSsls').then(response => {
+    return (response.length > 0)
+  }).catch(() => {
+    return true
+  })
+}
+
+export const hasRadiusTlss = () => {
+  return store.dispatch('config/getRadiusTlss').then(response => {
+    return (response.length > 0)
+  }).catch(() => {
+    return true
+  })
+}
+
 export const hasRealms = () => {
   return store.dispatch('config/getRealms').then(response => {
     return (response.length > 0)
@@ -788,6 +828,56 @@ export const provisioningExists = (value) => {
   })
 }
 
+export const radiusEapExists = (value) => {
+  if (!value) return true
+  return store.dispatch('config/getRadiusEaps').then(response => {
+    if (response.length === 0) return true
+    else return response.filter(eap => eap.id.toLowerCase() === value.toLowerCase()).length > 0
+  }).catch(() => {
+    return true
+  })
+}
+
+export const radiusFastExists = (value) => {
+  if (!value) return true
+  return store.dispatch('config/getRadiusFasts').then(response => {
+    if (response.length === 0) return true
+    else return response.filter(fast => fast.id.toLowerCase() === value.toLowerCase()).length > 0
+  }).catch(() => {
+    return true
+  })
+}
+
+export const radiusOcspExists = (value) => {
+  if (!value) return true
+  return store.dispatch('config/getRadiusOcsps').then(response => {
+    if (response.length === 0) return true
+    else return response.filter(ocsp => ocsp.id.toLowerCase() === value.toLowerCase()).length > 0
+  }).catch(() => {
+    return true
+  })
+}
+
+export const radiusSslExists = (value) => {
+  if (!value) return true
+  return store.dispatch('config/getRadiusSsls').then(response => {
+    if (response.length === 0) return true
+    else return response.filter(ssl => ssl.id.toLowerCase() === value.toLowerCase()).length > 0
+  }).catch(() => {
+    return true
+  })
+}
+
+export const radiusTlsExists = (value) => {
+  if (!value) return true
+  return store.dispatch('config/getRadiusTlss').then(response => {
+    if (response.length === 0) return true
+    else return response.filter(tls => tls.id.toLowerCase() === value.toLowerCase()).length > 0
+  }).catch(() => {
+    return true
+  })
+}
+
 export const realmExists = (value) => {
   if (!value) return true
   return store.dispatch('config/getRealms').then(response => {
@@ -854,7 +944,17 @@ export const switchExists = (value) => {
     if (response.length === 0) return true
     else return response.filter(switche => switche.id.toLowerCase() === value.toLowerCase()).length > 0
   }).catch(() => {
-    return true
+      return true
+  })
+}
+
+export const switchNotExists = (value) => {
+  if (!value) return true
+  return store.dispatch('config/getSwitches').then((response) => {
+    if (response.length === 0) return false
+    else return response.filter(switche => switche.id.toLowerCase() === value.toLowerCase()).length === 0
+  }).catch(() => {
+      return true
   })
 }
 
@@ -868,6 +968,19 @@ export const switchGroupExists = (value) => {
   })
 }
 
+export const switchModeExists = (value) => {
+  if (!value) return true
+  return store.dispatch('$_switches/optionsBySwitchGroup', 'default').then((response) => {
+    const { meta: { mode: { allowed } = {} } = {} } = response
+    for (const { value: v } of allowed) {
+      if (v === value) return true
+    }
+    return false
+  }).catch(() => {
+    return true
+  })
+}
+
 export const switchTemplateExists = (value) => {
   if (!value) return true
   return store.dispatch('config/getSwitchTemplates').then(response => {
@@ -878,6 +991,22 @@ export const switchTemplateExists = (value) => {
   })
 }
 
+export const switchTypeExists = (value) => {
+  if (!value) return true
+  return store.dispatch('$_switches/optionsBySwitchGroup', 'default').then((response) => {
+    const { meta: { type: { allowed } = {} } = {} } = response
+    for (const { options } of allowed) {
+      for (let option of options) {
+        const { value: v } = option
+        if (v === value) return true
+      }
+    }
+    return false
+  }).catch(() => {
+    return true
+  })
+}
+
 export const syslogForwarderExists = (value) => {
   if (!value) return true
   return store.dispatch('config/getSyslogForwarders').then(response => {
