@@ -25,7 +25,7 @@ export const types = {
   ERROR: 'error'
 }
 
-export default new Vuex.Store({
+const store = new Vuex.Store({
   modules: {
     config,
     documentation,
@@ -43,3 +43,16 @@ export default new Vuex.Store({
   },
   strict: debug
 })
+
+export const reset = () => {
+  // Reset states and unregister temporary modules
+  Object.keys(store._modules.root._children).forEach(module => {
+    if (module[0] === '$' && module[1] === '_') {
+      store.unregisterModule(module)
+    } else {
+      store.commit(`${module}/$RESET`, null, { root: true })
+    }
+  })
+}
+
+export default store
