@@ -144,6 +144,21 @@ const api = {
   getProvisionings () {
     return apiCall({ url: 'config/provisionings', method: 'get' })
   },
+  getRadiusEaps () {
+    return apiCall({ url: 'config/radiusd/eap_profiles', method: 'get' })
+  },
+  getRadiusFasts () {
+    return apiCall({ url: 'config/radiusd/fast_profiles', method: 'get' })
+  },
+  getRadiusOcsps () {
+    return apiCall({ url: 'config/radiusd/ocsp_profiles', method: 'get' })
+  },
+  getRadiusSsls () {
+    return apiCall({ url: 'config/ssl_certificates', method: 'get' })
+  },
+  getRadiusTlss () {
+    return apiCall({ url: 'config/radiusd/tls_profiles', method: 'get' })
+  },
   getRealms () {
     return apiCall({ url: 'config/realms', method: 'get' })
   },
@@ -169,7 +184,7 @@ const api = {
     return apiCall({ url: 'config/switches', method: 'get', params: { limit: 1000 } })
   },
   getSwitchGroups () {
-    return apiCall({ url: 'config/switch_groups', method: 'get' })
+    return apiCall({ url: 'config/switch_groups', method: 'get', params: { limit: 1000 } })
   },
   getSwitchGroupMembers (id) {
     return apiCall({ url: `config/switch_group/${id}/members`, method: 'get' })
@@ -197,6 +212,20 @@ const api = {
   },
   postFixPermissions () {
     return apiCall({ url: 'config/fix_permissions', method: 'post' })
+  },
+  flattenCondition: (data) => {
+    return apiCall.postQuiet('config/flatten_condition', data).then(response => {
+      return response.data
+    }).catch(err => {
+      throw err
+    })
+  },
+  parseCondition: (data) => {
+    return apiCall.postQuiet('config/parse_condition', data).then(response => {
+      return response.data
+    }).catch(err => {
+      throw err
+    })
   }
 }
 
@@ -293,6 +322,16 @@ const initialState = () => { // set intitial states to `false` (not `[]` or `{}`
     portalModulesStatus: '',
     provisionings: false,
     provisioningsStatus: '',
+    radiusEaps: false,
+    radiusEapsStatus: '',
+    radiusFasts: false,
+    radiusFastsStatus: '',
+    radiusOcsps: false,
+    radiusOcspsStatus: '',
+    radiusSsls: false,
+    radiusSslsStatus: '',
+    radiusTlss: false,
+    radiusTlssStatus: '',
     realms: false,
     realmsStatus: '',
     roles: false,
@@ -487,6 +526,21 @@ const getters = {
   isLoadingProvisionings: state => {
     return state.provisioningsStatus === types.LOADING
   },
+  isLoadingRadiusEaps: state => {
+    return state.radiusEapsStatus === types.LOADING
+  },
+  isLoadingRadiusFasts: state => {
+    return state.radiusFastsStatus === types.LOADING
+  },
+  isLoadingRadiusOcsps: state => {
+    return state.radiusOcspsStatus === types.LOADING
+  },
+  isLoadingRadiusSsls: state => {
+    return state.radiusSslsStatus === types.LOADING
+  },
+  isLoadingRadiusTlss: state => {
+    return state.radiusTlssStatus === types.LOADING
+  },
   isLoadingRealms: state => {
     return state.realmsStatus === types.LOADING
   },
@@ -536,7 +590,7 @@ const getters = {
     return state.wrixLocationsStatus === types.LOADING
   },
   accessDurationsList: state => {
-    if (!state.baseGuestsAdminRegistration) return []
+    if (!state.baseGuestsAdminRegistration || !('access_duration_choices' in state.baseGuestsAdminRegistration)) return []
     return state.baseGuestsAdminRegistration.access_duration_choices.split(',').map((accessDuration) => {
       return duration.deserialize(accessDuration)
     }).sort((a, b) => {
@@ -818,19 +872,14 @@ const actions = {
     if (getters.isLoadingBaseGuestsAdminRegistration) {
       return Promise.resolve(state.baseGuestsAdminRegistration)
     }
-    if (acl.$can('read', 'configuration_main')) {
-      if (!state.baseGuestsAdminRegistration) {
-        commit('BASE_GUESTS_ADMIN_REGISTRATION_REQUEST')
-        return api.getBaseGuestsAdminRegistration().then(response => {
-          commit('BASE_GUESTS_ADMIN_REGISTRATION_UPDATED', response.data.item)
-          return state.baseGuestsAdminRegistration
-        })
-      } else {
-        return Promise.resolve(state.baseGuestsAdminRegistration)
-      }
+    if (!state.baseGuestsAdminRegistration) {
+      commit('BASE_GUESTS_ADMIN_REGISTRATION_REQUEST')
+      return api.getBaseGuestsAdminRegistration().then(response => {
+        commit('BASE_GUESTS_ADMIN_REGISTRATION_UPDATED', response.data.item)
+        return state.baseGuestsAdminRegistration
+      })
     } else {
-      commit('BASE_GUESTS_ADMIN_REGISTRATION_UPDATED', {})
-      return state.baseGuestsAdminRegistration
+      return Promise.resolve(state.baseGuestsAdminRegistration)
     }
   },
   getBaseInline: ({ state, getters, commit }) => {
@@ -1271,6 +1320,76 @@ const actions = {
       return Promise.resolve(state.provisionings)
     }
   },
+  getRadiusEaps: ({ state, getters, commit }) => {
+    if (getters.isLoadingRadiusEaps) {
+      return Promise.resolve(state.radiusEaps)
+    }
+    if (!state.radiusEaps) {
+      commit('RADIUS_EAPS_REQUEST')
+      return api.getRadiusEaps().then(response => {
+        commit('RADIUS_EAPS_UPDATED', response.data.items)
+        return state.radiusEaps
+      })
+    } else {
+      return Promise.resolve(state.radiusEaps)
+    }
+  },
+  getRadiusFasts: ({ state, getters, commit }) => {
+    if (getters.isLoadingRadiusFasts) {
+      return Promise.resolve(state.radiusFasts)
+    }
+    if (!state.radiusFasts) {
+      commit('RADIUS_FASTS_REQUEST')
+      return api.getRadiusFasts().then(response => {
+        commit('RADIUS_FASTS_UPDATED', response.data.items)
+        return state.radiusFasts
+      })
+    } else {
+      return Promise.resolve(state.radiusFasts)
+    }
+  },
+  getRadiusOcsps: ({ state, getters, commit }) => {
+    if (getters.isLoadingRadiusOcsps) {
+      return Promise.resolve(state.radiusOcsps)
+    }
+    if (!state.radiusOcsps) {
+      commit('RADIUS_OCSPS_REQUEST')
+      return api.getRadiusOcsps().then(response => {
+        commit('RADIUS_OCSPS_UPDATED', response.data.items)
+        return state.radiusOcsps
+      })
+    } else {
+      return Promise.resolve(state.radiusOcsps)
+    }
+  },
+  getRadiusSsls: ({ state, getters, commit }) => {
+    if (getters.isLoadingRadiusSsls) {
+      return Promise.resolve(state.radiusSsls)
+    }
+    if (!state.radiusSsls) {
+      commit('RADIUS_SSLS_REQUEST')
+      return api.getRadiusSsls().then(response => {
+        commit('RADIUS_SSLS_UPDATED', response.data.items)
+        return state.radiusSsls
+      })
+    } else {
+      return Promise.resolve(state.radiusSsls)
+    }
+  },
+  getRadiusTlss: ({ state, getters, commit }) => {
+    if (getters.isLoadingRadiusTlss) {
+      return Promise.resolve(state.radiusTlss)
+    }
+    if (!state.radiusTlss) {
+      commit('RADIUS_TLSS_REQUEST')
+      return api.getRadiusTlss().then(response => {
+        commit('RADIUS_TLSS_UPDATED', response.data.items)
+        return state.radiusTlss
+      })
+    } else {
+      return Promise.resolve(state.radiusTlss)
+    }
+  },
   getRealms: ({ state, getters, commit }) => {
     if (getters.isLoadingRealms) {
       return Promise.resolve(state.realms)
@@ -1532,6 +1651,22 @@ const actions = {
     } else {
       return Promise.resolve(state.wrixLocations)
     }
+  },
+  stringifyCondition: ({ commit }, json) => {
+    return api.flattenCondition({ condition: json }).then(response => {
+      const { item: { condition_string } = {} } = response
+      return condition_string
+    }).catch(err => {
+      throw err
+    })
+  },
+  parseCondition: ({ commit }, string) => {
+    return api.parseCondition({ condition: string }).then(response => {
+      const { item: { condition } = {} } = response
+      return condition
+    }).catch(err => {
+      throw err
+    })
   }
 }
 
@@ -1731,13 +1866,6 @@ const mutations = {
     state.connectionProfiles = connectionProfiles
     state.connectionProfilesStatus = types.SUCCESS
   },
-  SELF_SERVICES_REQUEST: (state) => {
-    state.selfServicesStatus = types.LOADING
-  },
-  SELF_SERVICES_UPDATED: (state, selfServices) => {
-    state.selfServices = selfServices
-    state.selfServicesStatus = types.SUCCESS
-  },
   DOMAINS_REQUEST: (state) => {
     state.domainsStatus = types.LOADING
   },
@@ -1855,6 +1983,41 @@ const mutations = {
     state.provisionings = provisionings
     state.provisioningsStatus = types.SUCCESS
   },
+  RADIUS_EAPS_REQUEST: (state) => {
+    state.radiusEapsStatus = types.LOADING
+  },
+  RADIUS_EAPS_UPDATED: (state, eaps) => {
+    state.radiusEaps = eaps
+    state.radiusEapsStatus = types.SUCCESS
+  },
+  RADIUS_FASTS_REQUEST: (state) => {
+    state.radiusFastsStatus = types.LOADING
+  },
+  RADIUS_FASTS_UPDATED: (state, eaps) => {
+    state.radiusFasts = eaps
+    state.radiusFastsStatus = types.SUCCESS
+  },
+  RADIUS_OCSPS_REQUEST: (state) => {
+    state.radiusOcspsStatus = types.LOADING
+  },
+  RADIUS_OCSPS_UPDATED: (state, eaps) => {
+    state.radiusOcsps = eaps
+    state.radiusOcspsStatus = types.SUCCESS
+  },
+  RADIUS_SSLS_REQUEST: (state) => {
+    state.radiusSslsStatus = types.LOADING
+  },
+  RADIUS_SSLS_UPDATED: (state, eaps) => {
+    state.radiusSsls = eaps
+    state.radiusSslsStatus = types.SUCCESS
+  },
+  RADIUS_TLSS_REQUEST: (state) => {
+    state.radiusTlssStatus = types.LOADING
+  },
+  RADIUS_TLSS_UPDATED: (state, eaps) => {
+    state.radiusTlss = eaps
+    state.radiusTlssStatus = types.SUCCESS
+  },
   REALMS_REQUEST: (state) => {
     state.realmsStatus = types.LOADING
   },
@@ -1894,6 +2057,13 @@ const mutations = {
     state.securityEvents = ref
     state.securityEventsStatus = types.SUCCESS
   },
+  SELF_SERVICES_REQUEST: (state) => {
+    state.selfServicesStatus = types.LOADING
+  },
+  SELF_SERVICES_UPDATED: (state, selfServices) => {
+    state.selfServices = selfServices
+    state.selfServicesStatus = types.SUCCESS
+  },
   SOURCES_REQUEST: (state) => {
     state.sourcesStatus = types.LOADING
   },
