@@ -365,7 +365,7 @@ export default {
     })
   },
   filterEnginesCollection: collection => {
-    return apiCall.getQuiet(['config', 'filter_engines', collection]).then(response => {
+    return apiCall.get(['config', 'filter_engines', collection], { params: { limit: 1000 } }).then(response => {
       return response.data
     }).catch(err => {
       throw err
@@ -408,20 +408,6 @@ export default {
   deleteFilterEngine: ({ resource, id }) => {
     return apiCall.delete(['config', 'filter_engines', resource, id])
   },
-  flattenCondition: (data) => {
-    return apiCall.postQuiet('config/filter_engines/flatten_condition', data).then(response => {
-      return response.data
-    }).catch(err => {
-      throw err
-    })
-  },
-  parseCondition: (data) => {
-    return apiCall.postQuiet('config/filter_engines/parse_condition', data).then(response => {
-      return response.data
-    }).catch(err => {
-      throw err
-    })
-  },
 
   /**
    * Fingerbank Profiling
@@ -1141,6 +1127,175 @@ export default {
     return apiCall.delete(['config', 'provisioning', id])
   },
 
+  /**
+   * RADIUS
+   */
+  radiusEaps: params => {
+    return apiCall.get('config/radiusd/eap_profiles', { params }).then(response => {
+      return response.data
+    })
+  },
+  radiusEapsOptions: () => {
+    return apiCall.options('config/radiusd/eap_profiles').then(response => {
+      return response.data
+    })
+  },
+  radiusEap: id => {
+    return apiCall.get(['config', 'radiusd', 'eap_profile', id]).then(response => {
+      return response.data.item
+    })
+  },
+  radiusEapOptions: id => {
+    return apiCall.options(['config', 'radiusd', 'eap_profile', id]).then(response => {
+      return response.data
+    })
+  },
+  createRadiusEap: data => {
+    return apiCall.post('config/radiusd/eap_profiles', data).then(response => {
+      return response.data
+    })
+  },
+  updateRadiusEap: data => {
+    return apiCall.patch(['config', 'radiusd', 'eap_profile', data.id], data).then(response => {
+      return response.data
+    })
+  },
+  deleteRadiusEap: id => {
+    return apiCall.delete(['config', 'radiusd', 'eap_profile', id])
+  },
+  radiusFasts: params => {
+    return apiCall.get('config/radiusd/fast_profiles', { params }).then(response => {
+      return response.data
+    })
+  },
+  radiusFastsOptions: () => {
+    return apiCall.options('config/radiusd/fast_profiles').then(response => {
+      return response.data
+    })
+  },
+  radiusFast: id => {
+    return apiCall.get(['config', 'radiusd', 'fast_profile', id]).then(response => {
+      return response.data.item
+    })
+  },
+  radiusFastOptions: id => {
+    return apiCall.options(['config', 'radiusd', 'fast_profile', id]).then(response => {
+      return response.data
+    })
+  },
+  createRadiusFast: data => {
+    return apiCall.post('config/radiusd/fast_profiles', data).then(response => {
+      return response.data
+    })
+  },
+  updateRadiusFast: data => {
+    return apiCall.patch(['config', 'radiusd', 'fast_profile', data.id], data).then(response => {
+      return response.data
+    })
+  },
+  deleteRadiusFast: id => {
+    return apiCall.delete(['config', 'radiusd', 'fast_profile', id])
+  },
+  radiusSsls: params => {
+    return apiCall.get('config/ssl_certificates', { params }).then(response => {
+      return response.data
+    })
+  },
+  radiusSslsOptions: () => {
+    return apiCall.options('config/ssl_certificates').then(response => {
+      return response.data
+    })
+  },
+  radiusSsl: id => {
+    return apiCall.get(['config', 'ssl_certificate', id]).then(response => {
+      return response.data.item
+    })
+  },
+  radiusSslOptions: id => {
+    return apiCall.options(['config', 'ssl_certificate', id]).then(response => {
+      return response.data
+    })
+  },
+  createRadiusSsl: data => {
+    return apiCall.post('config/ssl_certificates', data).then(response => {
+      return response.data
+    })
+  },
+  updateRadiusSsl: data => {
+    return apiCall.patch(['config', 'ssl_certificate', data.id], data).then(response => {
+      return response.data
+    })
+  },
+  deleteRadiusSsl: id => {
+    return apiCall.delete(['config', 'ssl_certificate', id])
+  },
+  radiusTlss: params => {
+    return apiCall.get('config/radiusd/tls_profiles', { params }).then(response => {
+      return response.data
+    })
+  },
+  radiusTlssOptions: () => {
+    return apiCall.options('config/radiusd/tls_profiles').then(response => {
+      return response.data
+    })
+  },
+  radiusTls: id => {
+    return apiCall.get(['config', 'radiusd', 'tls_profile', id]).then(response => {
+      return response.data.item
+    })
+  },
+  radiusTlsOptions: id => {
+    return apiCall.options(['config', 'radiusd', 'tls_profile', id]).then(response => {
+      return response.data
+    })
+  },
+  createRadiusTls: data => {
+    return apiCall.post('config/radiusd/tls_profiles', data).then(response => {
+      return response.data
+    })
+  },
+  updateRadiusTls: data => {
+    return apiCall.patch(['config', 'radiusd', 'tls_profile', data.id], data).then(response => {
+      return response.data
+    })
+  },
+  deleteRadiusTls: id => {
+    return apiCall.delete(['config', 'radiusd', 'tls_profile', id])
+  },
+  radiusOcsps: params => {
+    return apiCall.get('config/radiusd/ocsp_profiles', { params }).then(response => {
+      return response.data
+    })
+  },
+  radiusOcspsOptions: () => {
+    return apiCall.options('config/radiusd/ocsp_profiles').then(response => {
+      return response.data
+    })
+  },
+  radiusOcsp: id => {
+    return apiCall.get(['config', 'radiusd', 'ocsp_profile', id]).then(response => {
+      return response.data.item
+    })
+  },
+  radiusOcspOptions: id => {
+    return apiCall.options(['config', 'radiusd', 'ocsp_profile', id]).then(response => {
+      return response.data
+    })
+  },
+  createRadiusOcsp: data => {
+    return apiCall.post('config/radiusd/ocsp_profiles', data).then(response => {
+      return response.data
+    })
+  },
+  updateRadiusOcsp: data => {
+    return apiCall.patch(['config', 'radiusd', 'ocsp_profile', data.id], data).then(response => {
+      return response.data
+    })
+  },
+  deleteRadiusOcsp: id => {
+    return apiCall.delete(['config', 'radiusd', 'ocsp_profile', id])
+  },
+
   /**
    * Realms
    */
@@ -1177,6 +1332,11 @@ export default {
   deleteRealm: id => {
     return apiCall.delete(['config', 'realm', id])
   },
+  sortRealms: data => {
+    return apiCall.patch('config/realms/sort_items', data).then(response => {
+      return response
+    })
+  },
 
   /**
    * Roles
@@ -1365,7 +1525,7 @@ export default {
    * Switches
    */
   switches: params => {
-    return apiCall.get(['config', 'switches'], { params }).then(response => {
+    return apiCall.get(['config', 'switches'], { params: { ...params, raw: 1 } }).then(response => {
       return response.data
     })
   },
@@ -1380,8 +1540,18 @@ export default {
       })
     }
   },
+  switchesBulkImport: body => {
+    return apiCall.post('config/switches/bulk_import', body).then(response => {
+      return response.data.items
+    })
+  },
   switche: id => {
-    return apiCall.get(['config', 'switch', id]).then(response => {
+    return apiCall.get(['config', 'switch', id], { params: { skip_inheritance: true } }).then(response => {
+      return response.data.item
+    })
+  },
+  switcheQuiet: id => {
+    return apiCall.getQuiet(['config', 'switch', id], { params: { skip_inheritance: true } }).then(response => {
       return response.data.item
     })
   },
@@ -1391,7 +1561,8 @@ export default {
     })
   },
   createSwitch: data => {
-    return apiCall.post('config/switches', data).then(response => {
+    const post = data.quiet ? 'postQuiet' : 'post'
+    return apiCall[post]('config/switches', data).then(response => {
       return response.data
     })
   },
@@ -1404,12 +1575,15 @@ export default {
   deleteSwitch: id => {
     return apiCall.delete(['config', 'switch', id])
   },
+  invalidateSwitchCache: id => {
+    return apiCall.post(['config', 'switch', id, 'invalidate_cache'])
+  },
 
   /**
    * SwitchGroups
    */
   switchGroups: params => {
-    return apiCall.get(['config', 'switch_groups'], { params }).then(response => {
+    return apiCall.get(['config', 'switch_groups'], { params: { ...params, raw: 1 } }).then(response => {
       return response.data
     })
   },
@@ -1419,7 +1593,7 @@ export default {
     })
   },
   switchGroup: id => {
-    return apiCall.get(['config', 'switch_group', id]).then(response => {
+    return apiCall.get(['config', 'switch_group', id], { params: { skip_inheritance: true } }).then(response => {
       return response.data.item
     })
   },
