@@ -3,6 +3,7 @@ import { BButton } from 'bootstrap-vue'
 import pfFieldTypeValue from '@/components/pfFieldTypeValue'
 import pfFormChosen from '@/components/pfFormChosen'
 import pfFormFields from '@/components/pfFormFields'
+import pfFormHtml from '@/components/pfFormHtml'
 import pfFormInput from '@/components/pfFormInput'
 import pfFormPassword from '@/components/pfFormPassword'
 import pfFormRangeToggleDefault from '@/components/pfFormRangeToggleDefault'
@@ -21,7 +22,11 @@ import {
   isMacAddress,
   isPort,
   hasSwitches,
-  switchExists
+  switchExists,
+  switchNotExists,
+  switchTypeExists,
+  switchModeExists,
+  switchGroupExists
 } from '@/globals/pfValidators'
 import {
   required,
@@ -116,7 +121,10 @@ export const config = (context = {}) => {
           ]
         }]
       },
-      defaultRoute: { name: 'switches' }
+      defaultRoute: { name: 'switches' },
+      extraFields: {
+        raw: 1
+      }
     },
     searchableQuickCondition: (quickCondition) => {
       return {
@@ -881,6 +889,19 @@ export const viewFields = {
       ]
     }
   },
+  TenantId: (form = {}, meta = {}) => {
+    return {
+      label: i18n.t('Tenant'),
+      text: i18n.t('The tenant associated to this switch entry. Single tenant deployments should never have to modify this value.'),
+      cols: [
+        {
+          namespace: 'TenantId',
+          component: pfFormChosen,
+          attrs: attributesFromMeta(meta, 'TenantId')
+        }
+      ]
+    }
+  },
   type: (form = {}, meta = {}) => {
     const {
       type
@@ -1145,6 +1166,9 @@ export const viewFields = {
 }
 
 export const view = (form = {}, meta = {}) => {
+  const {
+    type
+  } = form
   const {
     advancedMode = false
   } = meta
@@ -1154,6 +1178,7 @@ export const view = (form = {}, meta = {}) => {
       rows: [
         viewFields.id(form, meta),
         viewFields.description(form, meta),
+        viewFields.TenantId(form, meta),
         viewFields.type(form, meta),
         viewFields.mode(form, meta),
         viewFields.group(form, meta),
@@ -1175,6 +1200,21 @@ export const view = (form = {}, meta = {}) => {
     {
       tab: i18n.t('Roles'),
       rows: [
+        {
+          if: !advancedMode && !type,
+          label: i18n.t('Role'),
+          cols: [
+            {
+              component: pfFormHtml,
+              attrs: {
+                html: `<div class="alert alert-warning">
+                  <strong>${i18n.t('Note')}</strong>
+                  ${i18n.t('Choose a Switch type, or enable advanced mode to manage roles.')}
+                </div>`
+              }
+            }
+          ]
+        },
         {
           if: advancedMode || supports(form, meta, ['RadiusDynamicVlanAssignment']),
           label: i18n.t('Role mapping by VLAN ID'),
@@ -1423,6 +1463,7 @@ export const validators = (form = {}, meta = {}) => {
       SNMPAuthPasswordTrap: validatorsFromMeta(meta, 'SNMPAuthPasswordTrap'),
       SNMPPrivProtocolTrap: validatorsFromMeta(meta, 'SNMPPrivProtocolTrap'),
       SNMPPrivPasswordTrap: validatorsFromMeta(meta, 'SNMPPrivPasswordTrap'),
+      TenantId: validatorsFromMeta(meta, 'TenantId', i18n.t('Tenant ID')),
       macSearchesMaxNb: validatorsFromMeta(meta, 'macSearchesMaxNb', i18n.t('Max')),
       macSearchesSleepInterval: validatorsFromMeta(meta, 'macSearchesSleepInterval', i18n.t('Interval')),
       cliTransport: validatorsFromMeta(meta, 'cliTransport', i18n.t('Transport')),
@@ -1435,3 +1476,45 @@ export const validators = (form = {}, meta = {}) => {
     }
   }
 }
+
+export const importFields = [
+  {
+    value: 'id',
+    text: i18n.t('Identifier'),
+    types: [fieldType.SUBSTRING],
+    required: true
+  },
+  {
+    value: 'description',
+    text: i18n.t('Description'),
+    types: [fieldType.SUBSTRING],
+    required: true
+  },
+  {
+    value: 'type',
+    text: i18n.t('Type'),
+    types: [fieldType.SUBSTRING],
+    required: false,
+    validators: {
+      [i18n.t('Switch type does not exist.')]: switchTypeExists
+    }
+  },
+  {
+    value: 'mode',
+    text: i18n.t('Mode'),
+    types: [fieldType.SUBSTRING],
+    required: false,
+    validators: {
+      [i18n.t('Switch mode does not exist.')]: switchModeExists
+    }
+  },
+  {
+    value: 'group',
+    text: i18n.t('Switch Group'),
+    types: [fieldType.SUBSTRING],
+    required: false,
+    validators: {
+      [i18n.t('Switch group does not exist.')]: switchGroupExists
+    }
+  }
+]
