@@ -19,19 +19,21 @@ const types = {
   ERROR: 'error'
 }
 
-const state = {
-  allCharts: {},
-  allChartsStatus: '',
-  charts: localStorage.getItem(STORAGE_CHARTS_KEY) ? JSON.parse(localStorage.getItem(STORAGE_CHARTS_KEY)) : [],
-  alarmsStatus: '',
-  alarms: {},
-  services: [],
-  servicesStatus: '',
-  clusterPromise: null,
-  cluster: null,
-  clusterStatus: '',
-  clusterServices: [],
-  clusterServicesStatus: ''
+const state = () => {
+  return {
+    allCharts: {},
+    allChartsStatus: '',
+    charts: localStorage.getItem(STORAGE_CHARTS_KEY) ? JSON.parse(localStorage.getItem(STORAGE_CHARTS_KEY)) : [],
+    alarmsStatus: '',
+    alarms: {},
+    services: [],
+    servicesStatus: '',
+    clusterPromise: null,
+    cluster: null,
+    clusterStatus: '',
+    clusterServices: [],
+    clusterServicesStatus: ''
+  }
 }
 
 const getters = {
@@ -367,6 +369,7 @@ const actions = {
     if (state.clusterServicesStatus !== types.LOADING) {
       commit('CLUSTER_SERVICES_REQUEST')
       Promise.all(state.cluster.map(server => {
+        commit('CLUSTER_SERVICES_UPDATED', { host: server.host, services: [] }) // placeholder to maintain natural order
         return api.clusterServices(server.host).then(server => {
           commit('CLUSTER_SERVICES_UPDATED', server)
         }).catch(() => {
@@ -506,7 +509,18 @@ const mutations = {
   },
   CLUSTER_SERVICES_UPDATED: (state, server) => {
     if (server) {
-      state.clusterServices.push(server)
+      let found = state.clusterServices.find(s => s.host === server.host)
+      if (found) { // replace
+        state.clusterServices = state.clusterServices.map(s => {
+          const { host } = s
+          return (host === server.host)
+            ? server
+            : s
+        })
+      }
+      else { // append
+        state.clusterServices.push(server)
+      }
     } else {
       // No more data -- done fetching services
       state.clusterServicesStatus = types.SUCCESS
