@@ -21,7 +21,7 @@ use pf::LDAP;
 use List::Util;
 use Net::LDAP::Util qw(escape_filter_value);
 use pf::config qw(%Config);
-use List::MoreUtils qw(uniq any);
+use List::MoreUtils qw(uniq any firstval none);
 use pf::StatsD::Timer;
 use pf::util::statsd qw(called);
 
@@ -61,6 +61,7 @@ has 'encryption' => (isa => 'Str', is => 'rw', required => 1);
 has 'scope' => (isa => 'Str', is => 'rw', required => 1);
 has 'usernameattribute' => (isa => 'Str', is => 'rw', required => 1);
 has 'searchattributes' => (isa => 'ArrayRef[Str]', is => 'rw', required => 0);
+has 'append_to_searchattributes' => (isa => 'Maybe[Str]', is => 'rw', required => 0);
 has '_cached_connection' => (is => 'rw');
 has 'cache_match' => ( isa => 'Bool', is => 'rw', default => '0' );
 has 'email_attribute' => (isa => 'Maybe[Str]', is => 'rw', default => 'mail');
@@ -85,18 +86,21 @@ sub dynamic_routing_module { 'Authentication::Login' }
 =cut
 
 sub available_attributes {
-  my $self = shift;
+    my $self = shift;
 
-  my $super_attributes = $self->SUPER::available_attributes;
-  my @ldap_attributes = $self->ldap_attributes;
+    my $super_attributes = $self->SUPER::available_attributes;
+    my @ldap_attributes = $self->ldap_attributes;
 
-  # We check if our username attribute is present, if not we add it.
-  my $usernameattribute = $self->{'usernameattribute'};
-  if ( length ($usernameattribute) && !grep {$_->{value} eq $usernameattribute } @ldap_attributes ) {
-    push (@ldap_attributes, { value => $usernameattribute, type => $Conditions::LDAP_ATTRIBUTE });
-  }
+    # We check if our username attribute is present, if not we add it.
+    my $usernameattribute = $self->{'usernameattribute'};
+    if ( length ($usernameattribute) && !grep {$_->{value} eq $usernameattribute } @ldap_attributes ) {
+        push (@ldap_attributes, { value => $usernameattribute, type => $Conditions::LDAP_ATTRIBUTE });
+    }
+    push(@$super_attributes, @ldap_attributes);
+    my %seen;
+    @$super_attributes = grep { ! $seen{$_->{value}}++ } @$super_attributes;
 
-  return [@$super_attributes, sort { $a->{value} cmp $b->{value} } @ldap_attributes];
+    return [{ value => $Conditions::LDAP_FILTER, type => $Conditions::LDAP_FILTER  }, sort { lc($a->{value}) cmp lc($b->{value}) } @$super_attributes]
 }
 
 =head2 ldap_attributes
@@ -110,6 +114,38 @@ sub ldap_attributes {
     return map { { value => $_, type => $Conditions::LDAP_ATTRIBUTE } } @{$Config{advanced}->{ldap_attributes}};
 }
 
+=head2 common_attributes
+
+Add the radius attributes to the common attributes
+
+=cut
+
+sub common_attributes {
+    my $self = shift;
+    my $super_common_attributes = $self->SUPER::common_attributes;
+    my @radius_attributes = map { {value => "radius_request.".$_, type => $Conditions::SUBSTRING}} qw(
+        TLS-Client-Cert-Serial
+        TLS-Client-Cert-Expiration
+        TLS-Client-Cert-Issuer
+        TLS-Client-Cert-Subject
+        TLS-Client-Cert-Common-Name
+        TLS-Client-Cert-Filename
+        TLS-Client-Cert-Subject-Alt-Name-Email
+        TLS-Client-Cert-X509v3-Extended-Key-Usage
+        TLS-Cert-Serial
+        TLS-Cert-Expiration
+        TLS-Cert-Issuer
+        TLS-Cert-Subject
+        TLS-Cert-Common-Name
+        TLS-Client-Cert-Subject-Alt-Name-Dns
+    );
+
+    push(@radius_attributes, map { {value => "radius_request.".$_, type => $Conditions::SUBSTRING}} @{$Config{radius_configuration}->{radius_attributes}});
+    push(@$super_common_attributes, @radius_attributes);
+
+    return $super_common_attributes;
+}
+
 =head2 authenticate
 
 =cut
@@ -252,10 +288,11 @@ match_rule
 sub match_rule {
     my ($self, $rule, $params, $extra) = @_;
     if ($self->is_rule_cacheable($rule)) {
-        return $self->cache->compute_with_undef($self->rule_cache_key($rule, $params, $extra), sub {
+        my $results = $self->cache->compute_with_undef($self->rule_cache_key($rule, $params, $extra), sub {
             $pf::StatsD::statsd->increment("pf::Authentication::Source::LDAPSource::match_rule.$self->{id}.cache_miss.count" );
-            return $self->SUPER::match_rule($rule, $params, $extra);
+            return [$self->SUPER::match_rule($rule, $params, $extra)];
         });
+        return @{$results // []};
     }
     return $self->SUPER::match_rule($rule, $params, $extra);
 }
@@ -313,16 +350,20 @@ match_in_subclass
 
 sub match_in_subclass {
     my ($self, $params, $rule, $own_conditions, $matching_conditions) = @_;
-    my $filter = $self->ldap_filter_for_conditions($own_conditions, $rule->match, $self->{'usernameattribute'}, $params);
+    my $basedn = $self->{'basedn'};
+    my ($filter, $forcedbasedn) = $self->ldap_filter_for_conditions($own_conditions, $rule->match, $self->{'usernameattribute'}, $params);
     my $id = $self->id;
     if (! defined($filter)) {
         $logger->error("[$id] Missing parameters to construct LDAP filter");
         $pf::StatsD::statsd->increment(called() . "." . $id . ".error.count" );
-        return undef;
+        return (undef, undef);
+    }
+    if (defined($forcedbasedn) && $forcedbasedn ne '') {
+        $basedn = $forcedbasedn;
     }
     my $rule_id = $rule->id;
-    $logger->debug("[$id $rule_id] Searching for $filter, from $self->{'basedn'}, with scope $self->{'scope'}");
-    return $self->_match_in_subclass($filter, $params, $rule, $own_conditions, $matching_conditions);
+    $logger->warn("[$id $rule_id] Searching for $filter, from $basedn, with scope $self->{'scope'}");
+    return $self->_match_in_subclass($basedn, $filter, $params, $rule, $own_conditions, $matching_conditions);
 }
 
 =head2 _match_in_subclass
@@ -333,12 +374,14 @@ C<$rule> is the rule instance that defines the conditions.
 
 C<$own_conditions> are the conditions specific to an LDAP source.
 
+C<$basedn> is the basedn of the search
+
 Conditions that match are added to C<$matching_conditions>.
 
 =cut
 
 sub _match_in_subclass {
-    my ($self, $filter, $params, $rule, $own_conditions, $matching_conditions) = @_;
+    my ($self, $basedn, $filter, $params, $rule, $own_conditions, $matching_conditions) = @_;
     my $timer_stat_prefix = called() . "." .  $self->{'id'};
     my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}",  level => 6});
 
@@ -346,19 +389,22 @@ sub _match_in_subclass {
     unless ( $cached_connection ) {
         my ($connection, $LDAPServer, $LDAPServerPort) = $self->_connect();
         if (! defined($connection)) {
-            return undef;
+            return (undef, undef);
         }
 
         $cached_connection = [$connection, $LDAPServer, $LDAPServerPort];
         $self->_cached_connection($cached_connection);
     }
     my ( $connection, $LDAPServer, $LDAPServerPort ) = @$cached_connection;
-
     my @attributes = map { $_->{'attribute'} } @{$own_conditions};
+    if (my $action = firstval { $_->type eq $Actions::SET_ROLE_FROM_SOURCE } @{$rule->{actions} // []}) {
+        push @attributes, $action->value;
+    }
+
     my $result = do {
         my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}.search",  level => 6});
         $connection->search(
-          base => $self->{'basedn'},
+          base => $basedn,
           filter => $filter,
           scope => $self->{'scope'},
           attrs => \@attributes
@@ -366,13 +412,14 @@ sub _match_in_subclass {
     };
 
     if ($result->is_error) {
-        $logger->error("[$self->{'id'}] Unable to execute search $filter from $self->{'basedn'} on $LDAPServer:$LDAPServerPort, we skip the rule.");
+        $logger->error("[$self->{'id'}] Unable to execute search $filter from $basedn on $LDAPServer:$LDAPServerPort, we skip the rule.");
         $pf::StatsD::statsd->increment(called() . "." . $self->{'id'} . ".error.count" );
-        return undef;
+        return (undef, undef);
     }
 
-    $logger->debug("[$self->{'id'} $rule->{'id'}] Found ".$result->count." results");
-    if ($result->count == 1) {
+    my $result_count = $result->count;
+    $logger->debug("[$self->{'id'} $rule->{'id'}] Found $result_count results");
+    if ($result_count == 1) {
         my $entry = $result->pop_entry();
         my $dn = $entry->dn;
         my $entry_matches = 1;
@@ -439,18 +486,26 @@ sub _match_in_subclass {
             # If we found a result, we push all conditions as matched ones.
             # That is normal, as we used them all to build our LDAP filter.
             $logger->trace("[$self->{'id'} $rule->{'id'}] Found a match ($dn)");
-            push @{ $matching_conditions }, @{ $own_conditions };
-            return $params->{'username'} || $params->{'email'};
+            if ( (any {$_->type eq $Actions::SET_ROLE_ON_NOT_FOUND } @{$rule->{actions} // []}) && (none {$_->type eq $Actions::SET_ROLE } @{$rule->{actions} // []}) ) {
+                $logger->trace("[$self->{'id'} $rule->{'id'}] match ($dn) but no set role action, continue");
+            } else {
+                push @{ $matching_conditions }, @{ $own_conditions };
+                return ((($params->{'username'} || $params->{'email'}) ? $entry : undef), $Actions::SET_ROLE_ON_NOT_FOUND);
+            }
         }
     }
-    elsif($result->count > 1) {
+    elsif($result_count > 1) {
         $logger->warn("[$self->{'id'} $rule->{'id'}] Found more than 1 match. Ignoring all of them. Make sure your filtering rules (on username and on email) can only return a single result");
     }
     else {
         $logger->debug("[$self->{'id'} $rule->{'id'}] No match found for this LDAP filter");
+        if (any {$_->type eq $Actions::SET_ROLE_ON_NOT_FOUND } @{$rule->{actions} // []} ) {
+            push @{ $matching_conditions }, @{ $own_conditions };
+            return ($params->{'username'} || $params->{'email'}, $Actions::SET_ROLE);
+        }
     }
 
-    return undef;
+    return (undef, undef);
 }
 
 =head2 test
@@ -504,6 +559,10 @@ sub ldap_filter_for_conditions {
   my ($self, $conditions, $match, $usernameattribute, $params) = @_;
   my $timer_stat_prefix = called() . "." .  $self->{'id'};
   my $timer = pf::StatsD::Timer->new({ 'stat' => "${timer_stat_prefix}",  level => 7});
+  if (my $filter = firstval { $_->operator eq $Conditions::MATCH_FILTER } @{$conditions // []}) {
+       return $self->update_template($filter->value, $params);
+  }
+  my $basedn;
 
   my (@ldap_conditions, $expression);
 
@@ -520,7 +579,10 @@ sub ldap_filter_for_conditions {
           my $operator = $condition->{'operator'};
           my $value = escape_filter_value($condition->{'value'});
           my $attribute = $condition->{'attribute'};
-
+          if ($attribute eq "basedn") {
+              $basedn = $attribute;
+              next;
+          }
           if ($operator eq $Conditions::EQUALS) {
               $str = "${attribute}=${value}";
           } elsif ($operator eq $Conditions::NOT_EQUALS) {
@@ -546,7 +608,18 @@ sub ldap_filter_for_conditions {
       }
   }
 
-  return $expression;
+  return ($expression, $basedn);
+}
+
+sub replaceVar {
+    my ($name, $params) = @_;
+    return escape_filter_value(exists $params->{$name} ? $params->{$name} : '');
+}
+
+sub update_template {
+    my ($self, $template, $params) = @_;
+    $template =~ s/\$\{([a-zA-Z0-9]+([._-][a-zA-Z0-9]+)*)\}/replaceVar($1, $params)/ge;
+    return $template;
 }
 
 =head2 search based on a attribute
@@ -612,14 +685,30 @@ Create the filter to search for the dn
 
 sub _makefilter {
     my ($self,$username) = @_;
+    my $append_search = defined($self->{'append_to_searchattributes'}) ? $self->{'append_to_searchattributes'} : '';
     if (@{$self->{'searchattributes'} // []}) {
         my $search = join ("", map { "($_=$username)" } uniq($self->{'usernameattribute'}, @{$self->{'searchattributes'}}));
-        return "(|$search)";
+        return "(&(|$search)".$append_search.")";
     } else {
         return '(' . "$self->{'usernameattribute'}=$username" . ')';
     }
 }
 
+sub lookupRole {
+    my ($self, $rule, $role_info, $params, $extra, $entry, $attributes) = @_;
+    if (ref($entry) eq '') {
+        return undef;
+    }
+    foreach my $attr ( $entry->attributes ) {
+        $$attributes->{"ldap_attribute"}->{$attr} = $entry->get_value( $attr, asref => 1) ;
+    }
+    if (ref($entry) && (my $action = firstval { $_->type eq $Actions::SET_ROLE_FROM_SOURCE } @{$rule->{actions} // []})) {
+        return scalar $entry->get_value($action->value);
+    }
+
+    return undef;
+}
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
@@ -648,6 +737,7 @@ USA.
 =cut
 
 __PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
+
 1;
 
 # vim: set shiftwidth=4:
