@@ -48,7 +48,7 @@ has log => sub {
 
 sub escape_char {
     my ($k) = @_;
-    if ($k eq '2f') {
+    if ($k eq '2f' || $k eq '2F') {
         return "\%$k";
     }
     return chr(hex($k));
@@ -308,6 +308,7 @@ sub setup_api_v1_config_routes {
     $self->setup_api_v1_config_pki_providers_routes($root);
     $self->setup_api_v1_config_portal_modules_routes($root);
     $self->setup_api_v1_config_provisionings_routes($root);
+    $self->setup_api_v1_config_radiusd_routes($root);
     $self->setup_api_v1_config_realms_routes($root);
     $self->setup_api_v1_config_roles_routes($root);
     $self->setup_api_v1_config_scans_routes($root);
@@ -317,6 +318,7 @@ sub setup_api_v1_config_routes {
     $self->setup_api_v1_config_switch_groups_routes($root);
     $self->setup_api_v1_config_syslog_forwarders_routes($root);
     $self->setup_api_v1_config_syslog_parsers_routes($root);
+    $self->setup_api_v1_config_ssl_certificates_routes($root);
     $self->setup_api_v1_config_template_switches_routes($root);
     $self->setup_api_v1_config_system_routes($root);
     $self->setup_api_v1_config_traffic_shaping_policies_routes($root);
@@ -334,6 +336,13 @@ sub setup_api_v1_config_misc_routes {
     my ($self, $root) = @_;
     $root->register_sub_action({ controller => 'Config', action => 'fix_permissions', method => 'POST' });
     $root->register_sub_action({ controller => 'Config', action => 'checkup', method => 'GET' });
+    $root->register_sub_actions(
+        {
+            method     => 'POST',
+            actions    => [qw(parse_condition flatten_condition)],
+            controller => 'Config'
+        }
+    );
     return ;
 }
 
@@ -591,18 +600,38 @@ sub setup_api_v1_nodes_routes {
     );
 
     $resource_route->register_sub_actions({
-        method => 'POST',
-        actions => [ qw( register deregister restart_switchport reevaluate_access apply_security_event close_security_event fingerbank_refresh park unpark) ],
+        method => 'PUT',
+        actions => [ qw( register deregister restart_switchport apply_security_event close_security_event fingerbank_refresh park unpark reevaluate_access) ],
         auditable => 1,
     });
 
+###TODO remove at v11
+    $resource_route->register_sub_actions({
+        method => 'POST',
+        actions => [ qw( register deregister restart_switchport apply_security_event close_security_event fingerbank_refresh park unpark reevaluate_access) ],
+        auditable => 1,
+    });
+    $collection_route->register_sub_actions({
+        method => 'POST',
+        actions => [
+        qw(
+          bulk_register bulk_deregister bulk_close_security_events
+          bulk_reevaluate_access bulk_restart_switchport bulk_apply_security_event
+          bulk_apply_role bulk_apply_bypass_role bulk_fingerbank_refresh
+          bulk_apply_bypass_vlan bulk_import
+          )
+        ],
+        auditable => 1
+    });
+###
+
     $resource_route->register_sub_actions({
         method => 'GET',
         actions => [ qw(fingerbank_info rapid7 security_events) ],
     });
 
     $collection_route->register_sub_actions({
-        method => 'POST',
+        method => 'PUT',
         actions => [
         qw(
           bulk_register bulk_deregister bulk_close_security_events
@@ -844,8 +873,10 @@ sub setup_api_v1_std_config_collection_routes {
     $root->register_sub_action({path => '', action => 'list', method => 'GET'});
     $root->register_sub_action({path => '', action => 'create', method => 'POST', auditable => 1});
     $root->register_sub_action({path => '', action => 'options', method => 'OPTIONS'});
-    $root->register_sub_action({action => 'sort_items', method => 'PATCH', auditable => 1});
+    $root->register_sub_actions({actions => [qw(sort_items bulk_update)], method => 'PATCH', auditable => 1});
     $root->register_sub_action({action => 'search', method => 'POST'});
+    $root->register_sub_action({action => 'bulk_delete', method => 'POST', auditable => 1});
+    $root->register_sub_action({action => 'bulk_import', method => 'POST', auditable => 1});
     return ;
 }
 
@@ -1114,6 +1145,52 @@ sub setup_api_v1_config_provisionings_routes {
     return ($collection_route, $resource_route);
 }
 
+=head2 setup_api_v1_config_radiusd_routes
+
+ setup_api_v1_config_radiusd_routes
+
+=cut
+
+sub setup_api_v1_config_radiusd_routes {
+    my ($self, $root) = @_;
+    my $radiusd_route = $root->any("/radiusd")->name("api.v1.Config.Radiusd");
+    my ($collection_route, $resource_route) =
+      $self->setup_api_v1_std_config_routes(
+        $radiusd_route,
+        "Config::Radiusd::FastProfiles",
+        "/fast_profiles",
+        "/fast_profile/#fast_profile_id",
+        "api.v1.Config.Radiusd.FastProfiles"
+    );
+
+    ($collection_route, $resource_route) =
+      $self->setup_api_v1_std_config_routes(
+        $radiusd_route,
+        "Config::Radiusd::TLSProfiles",
+        "/tls_profiles",
+        "/tls_profile/#tls_profile_id",
+        "api.v1.Config.Radiusd.TLSProfiles"
+    );
+
+      $self->setup_api_v1_std_config_routes(
+        $radiusd_route,
+        "Config::Radiusd::OCSPProfiles",
+        "/ocsp_profiles",
+        "/ocsp_profile/#ocsp_profile_id",
+        "api.v1.Config.Radiusd.OCSPProfiles"
+    );
+
+      $self->setup_api_v1_std_config_routes(
+        $radiusd_route,
+        "Config::Radiusd::EAPProfiles",
+        "/eap_profiles",
+        "/eap_profile/#eap_profile_id",
+        "api.v1.Config.Radiusd.EAPProfiles"
+    );
+
+    return ($collection_route, $resource_route);
+}
+
 =head2 setup_api_v1_config_realms_routes
 
  setup_api_v1_config_realms_routes
@@ -1963,6 +2040,26 @@ sub setup_api_v1_config_wmi_rules_routes {
     return ($collection_route, $resource_route);
 }
 
+=head2 setup_api_v1_config_ssl_certificates_routes
+
+setup_api_v1_config_ssl_certificates_routes
+
+=cut
+
+sub setup_api_v1_config_ssl_certificates_routes {
+    my ($self, $root) = @_;
+    my ($collection_route, $resource_route) =
+      $self->setup_api_v1_std_config_routes(
+        $root,
+        "Config::SSLCertificates",
+        "/ssl_certificates",
+        "/ssl_certificate/#ssl_certificate_id",
+        "api.v1.Config.SSLCertificates"
+    );
+
+    return ($collection_route, $resource_route);
+}
+
 =head2 setup_api_v1_config_filter_engines_routes
 
 setup_api_v1_config_filter_engines_routes
@@ -1980,13 +2077,6 @@ sub setup_api_v1_config_filter_engines_routes {
             controller => 'Config::FilterEngines'
         }
     );
-    $filter_engines_root->register_sub_actions(
-        {
-            method     => 'POST',
-            actions    => [qw(parse_condition flatten_condition)],
-            controller => 'Config::FilterEngines'
-        }
-    );
     my ($collection_route, $resource_route) =
       $self->setup_api_v1_std_config_routes(
         $filter_engines_root,
