@@ -395,7 +395,7 @@ sub desAssociate : Public : Fork {
         return;
     }
 
-    my ($switchdeauthMethod, $deauthTechniques) = $switch->deauthTechniques($switch->{'_deauthMethod'});
+    my ($switchdeauthMethod, $deauthTechniques) = $switch->deauthTechniques($switch->{'_deauthMethod'}, $postdata->{'connection_type'});
 
     my $filter = pf::access_filter::switch->new;
     $filter->filterSwitch('reevaluate',\$switch, $postdata);
@@ -1346,8 +1346,9 @@ sub fingerbank_nba_webhook :Public :RestPath(/fingerbank/nba/webhook){
 
     my $mac = pf::util::clean_mac($args->{mac});
     for my $event (@{$args->{data}->{events}}) {
-        pf::security_event::security_event_trigger( { 'mac' => $mac, 'tid' => "fingerbank_".lc($event), 'type' => "internal" } );
-        pf::security_event::security_event_trigger( { 'mac' => $mac, 'tid' => "fingerbank_".lc($event)."_".$args->{data}->{policy}, 'type' => "internal" } );
+        my $notes = "\nTriggered via Network Anomaly Detection policy '$args->{data}->{policy}'\n";
+        pf::security_event::security_event_trigger( { 'mac' => $mac, 'tid' => "fingerbank_".lc($event), 'type' => "internal", "notes" => $notes } );
+        pf::security_event::security_event_trigger( { 'mac' => $mac, 'tid' => "fingerbank_".lc($event)."_".$args->{data}->{policy}, 'type' => "internal", "notes" => $notes } );
     }
     return "ok";
 }
@@ -1496,7 +1497,7 @@ sub handle_accounting_metadata : Public {
     }
 
     if ($acct_status_type == $ACCOUNTING::STOP) {
-        my $profile_name = pf::Connection::ProfileFactory->get_profile_name($mac);
+        my ($profile_name, undef) = pf::Connection::ProfileFactory->get_profile_name($mac);
         my $profile = $pf::config::Profiles_Config{$profile_name};
         if (pf::util::isenabled($profile->{unreg_on_acct_stop}) && pf::util::isenabled($profile->{autoregister})) {
             $logger->info("Unregistering $mac on Accounting-Stop");
