@@ -135,6 +135,7 @@ our (
     %CAPTIVE_PORTAL,
 #realm.conf
     %ConfigRealm,
+    @ConfigOrderedRealm,
 #provisioning.conf
     %ConfigProvisioning,
 #domain.conf
@@ -173,6 +174,8 @@ our (
     %ConfigAuthenticationLdap,
 # Radius sources
     %ConfigAuthenticationRadius,
+# TLS configuration
+    %ConfigEAP,
 );
 
 BEGIN {
@@ -216,6 +219,7 @@ BEGIN {
         $DISTRIB $DIST_VERSION
         %Doc_Config
         %ConfigRealm
+        @ConfigOrderedRealm
         %ConfigProvisioning
         %ConfigDomain
         $default_pid
@@ -236,6 +240,7 @@ BEGIN {
         %ConfigSelfService
         %ConfigAuthenticationLdap
         %ConfigAuthenticationRadius
+        %ConfigEAP
     );
 }
 
@@ -278,6 +283,8 @@ tie %ConfigFirewallSSO, 'pfconfig::cached_hash', 'config::Firewall_SSO';
 
 tie %ConfigRealm, 'pfconfig::cached_hash', 'config::Realm', tenant_id_scoped => 1;
 
+tie @ConfigOrderedRealm, 'pfconfig::cached_array', 'config::OrderedRealm', tenant_id_scoped => 1;
+
 tie %ConfigProvisioning, 'pfconfig::cached_hash', 'config::Provisioning';
 
 tie %ConfigScan, 'pfconfig::cached_hash', 'config::Scan';
@@ -314,6 +321,9 @@ tie %ConfigAuthenticationLdap, 'pfconfig::cached_hash', 'resource::authenticatio
 
 tie %ConfigAuthenticationRadius, 'pfconfig::cached_hash', 'resource::authentication_sources_radius';
 
+tie %ConfigEAP, 'pfconfig::cached_hash', 'resource::eap_config';
+
+
 $thread = 0;
 
 my $logger = get_logger();
@@ -404,19 +414,6 @@ our $BANDWIDTH_UNITS_RE = qr/B|KB|MB|GB|TB/;
 
 =over
 
-=item os_detection -  check the os system
-
-=cut
-
-sub os_detection {
-    my $logger = get_logger();
-    if (-e '/etc/debian_version') {
-        return "debian";
-    }elsif (-e '/etc/redhat-release') {
-        return "rhel";
-    }
-}
-
 =item access_duration
 
 Calculate the unregdate from from specific trigger.
