@@ -31,6 +31,7 @@ use pf::config qw(
     $UNKNOWN
     $management_network
     %ConfigRealm
+    @ConfigOrderedRealm
     $HTTPS
     $HTTP
 );
@@ -55,7 +56,6 @@ use pf::file_paths qw(
 use pf::util;
 use pf::log;
 use pf::authentication;
-use pf::cluster;
 
 BEGIN {
   use Exporter ();
@@ -398,13 +398,13 @@ Returns the list of host and IP on which the portal is configured to listen
 sub portal_hosts {
     my @hosts;
     foreach my $net (@internal_nets) {
-        push @hosts, values(%{pf::cluster::members_ips($net->{Tint})});
+        push @hosts, values(%{pf::cluster::members_ips($net->{Tint})}) if $cluster_enabled;
         push @hosts, $net->{Tip} if defined($net->{Tip});
         push @hosts, $net->{Tvip} if defined($net->{Tvip});
         push @hosts, $net->{Tipv6_address} if defined($net->{Tipv6_address});
     }
 
-    push @hosts, values(%{pf::cluster::members_ips($management_network->{Tint})});
+    push @hosts, values(%{pf::cluster::members_ips($management_network->{Tint})}) if $cluster_enabled;
     push @hosts, $management_network->{Tip} if defined($management_network->{Tip});
     push @hosts, $management_network->{Tvip} if defined($management_network->{Tvip});
     push @hosts, $fqdn;
@@ -420,13 +420,19 @@ Find sources for a specific realm
 sub get_realm_authentication_source {
     my ( $username, $realm, $sources ) = @_;
     my $matched_realm = $realm;
+    foreach my $realm_key ( @pf::config::ConfigOrderedRealm ) {
+        if (defined($pf::config::ConfigRealm{$realm_key}->{regex}) && $pf::config::ConfigRealm{$realm_key}->{'regex'} ne '' && defined($realm) && $realm =~ /$pf::config::ConfigRealm{$realm_key}->{regex}/) {
+            $realm = $realm_key;
+            last;
+        }
+    }
     $matched_realm //= 'null';
     my @found = grep { $_->realmIsAllowed($realm) } @{$sources};
     if (@found == 0 && $realm ne 'default' && !(exists $pf::config::ConfigRealm{$realm})) {
         $matched_realm = 'default';
         @found = grep { $_->realmIsAllowed('default') } @{$sources};
     }
-    get_logger->debug("Used realm $realm is associated to the configured realm $matched_realm");
+    get_logger->debug("Used realm ". ((defined($realm)) ? $realm : "null") ." is associated to the configured realm $matched_realm");
 
     return \@found;
 }
@@ -660,12 +666,19 @@ Valid context are "portal" and "admin", basically any prefix to "_strip_username
 sub strip_username_if_needed {
     my ($username, $context) = @_;
     return $username unless(defined($username));
-    
+
     my $logger = get_logger;
 
     my ($stripped, $realm) = strip_username($username);
     $realm = $realm ? lc($realm) : undef;
-    
+
+    foreach my $realm_key ( @pf::config::ConfigOrderedRealm ) {
+        if (defined($pf::config::ConfigRealm{$realm_key}->{regex}) && $pf::config::ConfigRealm{$realm_key}->{'regex'} ne '' && defined($realm) && $realm =~ /$pf::config::ConfigRealm{$realm_key}->{regex}/) {
+            $realm = $realm_key;
+            last;
+        }
+    }
+
     my $realm_config = defined($realm) && exists($ConfigRealm{$realm}) ? $ConfigRealm{$realm} : $ConfigRealm{lc($pf::constants::realm::DEFAULT)};
 
     my $param = $context . "_strip_username";
