@@ -84,6 +84,7 @@ our (
     $suricata_categories_file,
     $nexpose_categories_file,
     $radius_filters_config_file,
+    $radius_filters_config_default_file,
     $billing_tiers_config_file,
     $dhcp_filters_config_file,
     $roles_config_file,
@@ -114,7 +115,12 @@ our (
     $fingerbank_default_config_file,
     $fingerbank_doc_file,
     $api_i18n_dir,
-    $iptable_config_file
+    $iptable_config_file,
+    $ssl_config_file, $ssl_default_config_file,
+    $tls_config_file, $tls_default_config_file,
+    $ocsp_config_file, $ocsp_default_config_file,
+    $eap_config_file, $eap_default_config_file,
+    $fast_config_file, $fast_default_config_file
 );
 
 BEGIN {
@@ -174,7 +180,7 @@ BEGIN {
         $pki_provider_config_file
         $suricata_categories_file
         $nexpose_categories_file
-        $radius_filters_config_file
+        $radius_filters_config_file $radius_filters_config_default_file
         $billing_tiers_config_file
         $dhcp_filters_config_file
         $roles_config_file
@@ -206,6 +212,11 @@ BEGIN {
         $fingerbank_doc_file
         $api_i18n_dir
         $iptable_config_file
+        $ssl_config_file $ssl_default_config_file
+        $tls_config_file $tls_default_config_file
+        $ocsp_config_file $ocsp_default_config_file
+        $eap_config_file $eap_default_config_file
+        $fast_config_file $fast_default_config_file
     );
 }
 
@@ -306,6 +317,7 @@ $domain_config_file = catfile($conf_dir,"domain.conf");
 $scan_config_file = catfile($conf_dir,"scan.conf");
 $wmi_config_file = catfile($conf_dir,"wmi.conf");
 $radius_filters_config_file = catfile($conf_dir,"radius_filters.conf");
+$radius_filters_config_default_file = catfile($conf_dir,"radius_filters.conf.defaults");
 $billing_tiers_config_file = catfile($conf_dir,"billing_tiers.conf");
 $dhcp_filters_config_file = catfile($conf_dir,"dhcp_filters.conf");
 $roles_config_file = catfile($conf_dir,"roles.conf");
@@ -322,6 +334,16 @@ $switch_filters_config_file = catfile($conf_dir,"switch_filters.conf");
 $stats_config_file = catfile($conf_dir, "stats.conf");
 $stats_config_default_file = catfile($conf_dir, "stats.conf.defaults");
 $iptable_config_file = catfile($conf_dir, "iptables.conf");
+$ssl_config_file = catfile($conf_dir,"ssl.conf");
+$ssl_default_config_file = catfile($conf_dir,"ssl.conf.defaults");
+$tls_config_file = catfile($conf_dir,"radiusd/tls.conf");
+$tls_default_config_file = catfile($conf_dir,"radiusd/tls.conf.defaults");
+$ocsp_config_file = catfile($conf_dir,"radiusd/ocsp.conf");
+$ocsp_default_config_file = catfile($conf_dir,"radiusd/ocsp.conf.defaults");
+$eap_config_file = catfile($conf_dir,"radiusd/eap_profiles.conf");
+$eap_default_config_file = catfile($conf_dir,"radiusd/eap_profiles.conf.defaults");
+$fast_config_file = catfile($conf_dir,"radiusd/fast.conf");
+$fast_default_config_file = catfile($conf_dir,"radiusd/fast.conf.defaults");
 
 $oui_url               = 'http://standards.ieee.org/regauth/oui/oui.txt';
 $dhcp_fingerprints_url = 'http://www.packetfence.org/dhcp_fingerprints.conf';
@@ -357,7 +379,7 @@ $captiveportal_default_profile_templates_path = catdir ($captiveportal_profile_t
     $vlan_filters_config_file,$vlan_filters_config_default_file,$firewall_sso_config_file,$scan_config_file,
     $wmi_config_file,$pfdetect_config_file,$pfqueue_config_file,
     $pki_provider_config_file,
-    $radius_filters_config_file,
+    $radius_filters_config_file, $radius_filters_config_default_file,
     $dhcp_filters_config_file,
     $roles_config_file,
     $dns_filters_config_file,
@@ -370,6 +392,7 @@ $captiveportal_default_profile_templates_path = catdir ($captiveportal_profile_t
     $fingerbank_collector_env_defaults_file,
     $portal_modules_config_file,
     $template_switches_config_file,
+    $ssl_config_file
 );
 
 $pffilter_socket_path = catfile($var_dir, "run/pffilter.sock");
