@@ -16,6 +16,9 @@ use strict;
 use warnings;
 use Moose;
 use pf::person;
+use pf::dal::tenant;
+use pf::config::tenant;
+use pf::error qw(is_error);
 extends qw(pf::pfmon::task);
 
 =head2 run
@@ -25,7 +28,17 @@ run the person cleanup task
 =cut
 
 sub run {
-    person_cleanup();
+    my ($status, $iter) = pf::dal::tenant->search(
+        -with_class => undef,
+    );
+    if (is_error($status)) {
+        return;
+    }
+
+    while (my $t = $iter->next) {
+        local $pf::config::tenant::CURRENT_TENANT = $t->{id};
+        person_cleanup();
+    }
 }
 
 =head1 AUTHOR
