@@ -16,6 +16,9 @@ use strict;
 use warnings;
 use Moose;
 use pf::security_event;
+use pf::dal::tenant;
+use pf::config::tenant;
+use pf::error qw(is_error);
 extends qw(pf::pfmon::task);
 
 has 'batch' => ( is => 'rw');
@@ -29,7 +32,18 @@ run the security_event maintenance task
 
 sub run {
     my ($self) = @_;
-    security_event_maintenance($self->batch, $self->timeout);
+    my ($batch, $timeout) = ($self->batch, $self->timeout);
+    my ($status, $iter) = pf::dal::tenant->search(
+        -with_class => undef,
+    );
+    if (is_error($status)) {
+        return;
+    }
+
+    while (my $t = $iter->next) {
+        local $pf::config::tenant::CURRENT_TENANT = $t->{id};
+        security_event_maintenance($batch, $timeout);
+    }
 }
 
 =head1 AUTHOR
