@@ -109,7 +109,8 @@ sub authorize {
     my $timer = pf::StatsD::Timer->new();
     my ($self, $radius_request) = @_;
     my $logger = $self->logger;
-    my ($do_auto_reg, %autoreg_node_defaults);
+    my ($do_auto_reg, %autoreg_node_defaults, $action);
+
     my($switch_mac, $switch_ip,$source_ip,$stripped_user_name,$realm) = $self->_parseRequest($radius_request);
     my $RAD_REPLY_REF;
 
@@ -225,6 +226,12 @@ sub authorize {
     $args->{'ssid'} = $ssid;
     $args->{'node_info'} = $node_obj;
     $args->{'fingerbank_info'} = pf::node::fingerbank_info($mac, $node_obj);
+    my $filter = pf::access_filter::radius->new;
+    my $rule = $filter->test('preProcess', $args);
+    if ($rule) {
+        my ($reply, $status) = $filter->handleAnswerInRule({%$rule, merge_answer => 'enabled' }, $args, $radius_request);
+        %$radius_request = %$reply;
+    }
     my $result = $role_obj->filterVlan('IsPhone',$args);
     # determine if we need to perform automatic registration
     # either the switch detects that this is a phone or we take the result from the vlan filters
@@ -256,12 +263,14 @@ sub authorize {
     $do_auto_reg = $role_obj->shouldAutoRegister($args);
     if ($do_auto_reg) {
         $args->{'autoreg'} = 1;
-        %autoreg_node_defaults = $role_obj->getNodeInfoForAutoReg($args);
+        (my $attributes, $action , %autoreg_node_defaults) = $role_obj->getNodeInfoForAutoReg($args);
+        $args->{'action'} = $action;
+        $args = { %$args, %$attributes } if (ref($attributes) eq 'HASH');
         $node_obj->merge(\%autoreg_node_defaults);
         $logger->debug("[$mac] auto-registering node");
         # automatic registration
         $info{autoreg} = 1;
-        ($status, $status_msg) = pf::registration::setup_node_for_registration($node_obj, \%info);
+        ($status, $status_msg) = pf::registration::setup_node_for_registration($node_obj, \%info, $action);
         if (is_error($status)) {
             $logger->error("auto-registration of node failed $status_msg");
             $do_auto_reg = 0;
@@ -290,6 +299,14 @@ sub authorize {
 
     # Fetch VLAN depending on node status
     my $role = $role_obj->fetchRoleForNode($args);
+
+    if (defined($role->{attributes}) && exists($role->{attributes})) {
+        $args = { %$args, %{$role->{'attributes'}} };
+    }
+
+    if (!exists($args->{'action'})) {
+        $args->{'action'} = $role->{action};
+    }
     my $vlan;
     $args->{'node_info'}{'source'} = $role->{'source'} if (defined($role->{'source'}) && $role->{'source'} ne '');
     $args->{'node_info'}{'portal'} = $role->{'portal'} if (defined($role->{'portal'}) && $role->{'portal'} ne '');
@@ -298,8 +315,8 @@ sub authorize {
     $args->{'wasInline'} = $role->{wasInline};
     $args->{'user_role'} = $role->{role};
 
-    my $filter = pf::access_filter::switch->new;
-    $filter->filterSwitch('radius_authorize',\$switch, $args);
+    my $switch_filter = pf::access_filter::switch->new;
+    $switch_filter->filterSwitch('radius_authorize',\$switch, $args);
 
     if (isenabled($switch->{_VlanMap})) {
         $vlan = $switch->getVlanByName($role->{role}) if (isenabled($switch->{_VlanMap}));
@@ -895,16 +912,20 @@ sub switch_access {
             $args->{'profile'} = $profile;
             @sources = $profile->getFilteredAuthenticationSources($args->{'stripped_user_name'}, $args->{'realm'});
     }
-    my ( $return, $message, $source_id, $extra ) = pf::authentication::authenticate( {
-            'username' =>  $radius_request->{'User-Name'},
-            'password' =>  $radius_request->{'User-Password'},
-            'rule_class' => $Rules::ADMIN,
-            'context' => $pf::constants::realm::RADIUS_CONTEXT,
-        }, @sources );
+    my ( $return, $message, $source_id, $extra );
+    $source_id = \@sources;
+    if (!defined($args->{'radius_request'}{'MS-CHAP-Challenge'})) {
+        ( $return, $message, $source_id, $extra ) = pf::authentication::authenticate( {
+                'username' =>  $radius_request->{'User-Name'},
+                'password' =>  $radius_request->{'User-Password'},
+                'rule_class' => $Rules::ADMIN,
+                'context' => $pf::constants::realm::RADIUS_CONTEXT,
+            }, @sources );
 
-    if ( !( defined($return) && $return == $TRUE ) ) {
-        $logger->info("User $args->{'username'} tried to login in $args->{'switch'}{'_id'} but authentication failed");
-        return [ $RADIUS::RLM_MODULE_FAIL, ( 'Reply-Message' => "Authentication failed on PacketFence" ) ];
+        if ( !( defined($return) && $return == $TRUE ) ) {
+            $logger->info("User $args->{'username'} tried to login in $args->{'switch'}{'_id'} but authentication failed");
+            return [ $RADIUS::RLM_MODULE_FAIL, ( 'Reply-Message' => "Authentication failed on PacketFence" ) ];
+        }
     }
     if ($connection->isVPN()) {
         return $switch->returnAuthorizeVPN($args);
@@ -912,7 +933,8 @@ sub switch_access {
         my $merged = { %$options, %$args };
         $merged->{'rule_class'} = $Rules::ADMIN;
         $merged->{'context'} = $pf::constants::realm::RADIUS_CONTEXT;
-        my $matched = pf::authentication::match2($source_id, $merged, $extra);
+        my $attributes;
+        my $matched = pf::authentication::match2($source_id, $merged, $extra, \$attributes);
         my $value = $matched->{values}{$Actions::SET_ACCESS_LEVEL} if $matched;
         if ($value) {
             my @values = split(',', $value);
