@@ -22,7 +22,7 @@ has '+name' => (default => sub { 'galera-autofix' } );
 
 sub isManaged {
     my ($self) = @_;
-    return $cluster_enabled;
+    return $self->SUPER::isManaged() && $cluster_enabled;
 }
 
 
