@@ -46,6 +46,7 @@ use pf::config qw(
     $local_secret
     @radius_ints
     %ConfigAuthenticationLdap
+    %ConfigEAP
 );
 
 tie my @cli_switches, 'pfconfig::cached_array', 'resource::cli_switches';
@@ -125,6 +126,11 @@ Generates the packetfence and packetfence-tunnel configuration file
 sub generate_radiusd_sitesconf {
     my %tags;
 
+    $tags{'authorize_eap_choice'} = "";
+    $tags{'authentication_auth_type'} = "";
+
+    generate_eap_choice(\$tags{'authorize_eap_choice'}, \$tags{'authentication_auth_type'});
+
     if(isenabled($Config{radius_configuration}{record_accounting_in_sql})){
         $tags{'accounting_sql'} = "sql";
     }
@@ -133,9 +139,8 @@ sub generate_radiusd_sitesconf {
     }
     if(isenabled($Config{radius_configuration}{filter_in_packetfence_authorize})){
         $tags{'authorize_filter'} .= <<"EOT";
-        if ( !EAP-Message ) {
-             rest
-        }
+        rest
+
 EOT
     }
     else {
@@ -162,18 +167,22 @@ EOT
 
     $tags{'local_realm'} = '';
     my @realms;
-    foreach my $realm ( sort keys %pf::config::ConfigRealm ) {
+    foreach my $realm ( @pf::config::ConfigOrderedRealm ) {
         if (isenabled($pf::config::ConfigRealm{$realm}->{'radius_auth_compute_in_pf'})) {
-            push (@realms, "Realm == \"$realm\"");
+            if (defined $pf::config::ConfigRealm{$realm}->{'regex'} && $pf::config::ConfigRealm{$realm}->{'regex'} ne '') {
+                push (@realms, "Realm =~ /$pf::config::ConfigRealm{$realm}->{'regex'}/");
+            } else {
+                push (@realms, "Realm == \"$realm\"");
+            }
         }
     }
     if (@realms) {
-        $tags{'local_realm'} .= 'if ( ';
+        $tags{'local_realm'} .= '        if ( ';
         $tags{'local_realm'} .=  join(' || ', @realms);
         $tags{'local_realm'} .= ' ) {'."\n";
         $tags{'local_realm'} .= <<"EOT";
-    rest
-}
+            rest
+        }
 EOT
     }
 
@@ -218,7 +227,7 @@ EOT
 
     $tags{'userPrincipalName'} = '';
     my $flag = $TRUE;
-    foreach my $realm ( sort keys %pf::config::ConfigRealm ) {
+    foreach my $realm ( @pf::config::ConfigOrderedRealm ) {
         if (isenabled($pf::config::ConfigRealm{$realm}->{'permit_custom_attributes'}) && (scalar @{$ConfigAuthenticationLdap{$pf::config::ConfigRealm{$realm}->{ldap_source}}->{searchattributes}})) {
             if ($flag) {
                 $tags{'userPrincipalName'} .= <<"EOT";
@@ -230,10 +239,15 @@ EOT
 EOT
             }
             $flag = $FALSE;
-        $tags{'userPrincipalName'} .= <<"EOT";
-        if (Realm == \"$realm\" ) {
-            $pf::config::ConfigRealm{$realm}->{ldap_source}
-        }
+            if (defined $pf::config::ConfigRealm{$realm}->{'regex'} && $pf::config::ConfigRealm{$realm}->{'regex'} ne '') {
+                $tags{'userPrincipalName'} .= "            if (Realm =~ /$pf::config::ConfigRealm{$realm}->{'regex'}/) {";
+            } else {
+                $tags{'userPrincipalName'} .= "            if (Realm == \"$realm\") {";
+            }
+            $tags{'userPrincipalName'} .= <<"EOT";
+
+                $pf::config::ConfigRealm{$realm}->{ldap_source}
+            }
 EOT
         }
     }
@@ -244,6 +258,11 @@ EOT
 EOT
     }
 
+    $tags{'authorize_eap_choice'} = "";
+    $tags{'authentication_auth_type'} = "";
+
+    generate_eap_choice(\$tags{'authorize_eap_choice'}, \$tags{'authentication_auth_type'});
+
     $tags{'template'}    = "$conf_dir/raddb/sites-enabled/packetfence-tunnel";
     parse_template( \%tags, "$conf_dir/radiusd/packetfence-tunnel", "$install_dir/raddb/sites-enabled/packetfence-tunnel" );
 
@@ -387,7 +406,11 @@ EOT
                 if (isenabled($pf::config::ConfigRealm{$realm}->{'eduroam_radius_auth_compute_in_pf'})) {
                     push (@realms, "Realm == \"eduroam.$realm\"");
                 }
-                $tags{'local_realm'} .= '            if ( Realm == "'.$realm.'" ) {'."\n";
+                if (defined $pf::config::ConfigRealm{$realm}->{'regex'} && $pf::config::ConfigRealm{$realm}->{'regex'} ne '') {
+                    $tags{'local_realm'} .= '            if ( "Realm =~ /"'.$pf::config::ConfigRealm{$realm}->{'regex'}.'"/" ) {'."\n";
+                } else {
+                    $tags{'local_realm'} .= '            if ( Realm == "'.$realm.'" ) {'."\n";
+                }
                 $tags{'local_realm'} .= <<"EOT";
                 update control {
                     Proxy-To-Realm := "eduroam.$realm"
@@ -397,7 +420,11 @@ EOT
             }
             if ($pf::config::ConfigRealm{$realm}->{'eduroam_radius_acct'} ) {
                 $found_acct = $TRUE;
-                $tags{'local_realm_acct'} .= '            if ( Realm == "'.$realm.'" ) {'."\n";
+                if (defined $pf::config::ConfigRealm{$realm}->{'regex'} && $pf::config::ConfigRealm{$realm}->{'regex'} ne '') {
+                    $tags{'local_realm_acct'} .= '            if ( "Realm =~ /"'.$pf::config::ConfigRealm{$realm}->{'regex'}.'"/" ) {'."\n";
+                } else {
+                    $tags{'local_realm_acct'} .= '            if ( Realm == "'.$realm.'" ) {'."\n";
+                }
                 $tags{'local_realm_acct'} .= <<"EOT";
                 update control {
                     Proxy-To-Realm := "eduroam.$realm"
@@ -409,7 +436,11 @@ EOT
         my @local_realms;
         foreach my $realm ( @{$eduroam_authentication_source[0]{'local_realm'}} ) {
             if (!$pf::config::ConfigRealm{$realm}->{'eduroam_radius_auth'} ) {
-                push (@local_realms, "Realm == \"$realm\"");
+                 if (defined $pf::config::ConfigRealm{$realm}->{'regex'} && $pf::config::ConfigRealm{$realm}->{'regex'} ne '') {
+                     push (@local_realms, "Realm =~ /$pf::config::ConfigRealm{$realm}->{'regex'}/");
+                 } else {
+                     push (@local_realms, "Realm == \"$realm\"");
+                 }
             }
         }
         if (@local_realms) {
@@ -434,7 +465,7 @@ EOT
             }
 EOT
         } else {
-            $tags{'local_realm_exception'} .= 'reject';
+            $tags{'local_realm_exception'} .= '            reject';
         }
         if ($found_acct) {
             $tags{'local_realm_acct'} .= '        }';
@@ -444,7 +475,11 @@ EOT
         $tags{'reject_realm'} = '';
         my @reject_realms;
         foreach my $reject_realm ( @{$eduroam_authentication_source[0]{'reject_realm'}} ) {
-             push (@reject_realms, "Realm == \"$reject_realm\"");
+                 if (defined $pf::config::ConfigRealm{$reject_realm}->{'regex'} && $pf::config::ConfigRealm{$reject_realm}->{'regex'} ne '') {
+                     push (@reject_realms, "Realm =~ /$pf::config::ConfigRealm{$reject_realm}->{'regex'}/");
+                 } else {
+                     push (@reject_realms, "Realm == \"$reject_realm\"");
+                 }
         }
         if (@reject_realms) {
             $tags{'reject_realm'} .= '            if ( ';
@@ -466,6 +501,38 @@ EOT
         }
 EOT
         }
+        $tags{'authentication_auth_type'} = "";
+        $tags{'authorize_eap_choice'} = "";
+
+        generate_eap_choice(\$tags{'authorize_eap_choice'}, \$tags{'authentication_auth_type'});
+
+        if(isenabled($Config{radius_configuration}{filter_in_eduroam_authorize})){
+        $tags{'authorize_filter'} .= <<"EOT";
+        rest
+
+EOT
+        }
+        else {
+            $tags{'authorize_filter'} = "# filter not activated because explicitly disabled in pf.conf";
+        }
+        if(isenabled($Config{radius_configuration}{filter_in_eduroam_pre_proxy})){
+            $tags{'pre_proxy_filter'} = "rest";
+        }
+        else {
+            $tags{'pre_proxy_filter'} = "# filter not activated because explicitly disabled in pf.conf";
+        }
+        if(isenabled($Config{radius_configuration}{filter_in_eduroam_post_proxy})){
+            $tags{'post_proxy_filter'} = "rest";
+        }
+        else {
+            $tags{'post_proxy_filter'} = "# filter not activated because explicitly disabled in pf.conf";
+        }
+        if(isenabled($Config{radius_configuration}{filter_in_eduroam_preacct})){
+            $tags{'preacct_filter'} = "rest";
+        }
+        else {
+            $tags{'preacct_filter'} = "# filter not activated because explicitly disabled in pf.conf";
+        }
         parse_template( \%tags, "$conf_dir/radiusd/eduroam", "$install_dir/raddb/sites-available/eduroam" );
         symlink("$install_dir/raddb/sites-available/eduroam", "$install_dir/raddb/sites-enabled/eduroam");
 
@@ -551,14 +618,8 @@ Generates the eap.conf configuration file
 sub generate_radiusd_eapconf {
     my ($self, $tt) = @_;
     my $radius_configuration = $Config{radius_configuration};
-    my %vars = (
-        install_dir => $install_dir,
-        radius_configuration => $radius_configuration,
-        eap_fast_opaque_key => $radius_configuration->{eap_fast_opaque_key},
-        eap_fast_authority_identity => $radius_configuration->{eap_fast_authority_identity},
-        (map { $_ => 1 } (split ( /\s*,\s*/, $radius_configuration->{eap_authentication_types} // ''))),
-    );
-
+    my %vars;
+    $vars{'eap'} = \%ConfigEAP;
     $tt->process("$conf_dir/radiusd/eap.conf", \%vars, "$install_dir/raddb/mods-enabled/eap") or die $tt->error();
 }
 
@@ -619,26 +680,35 @@ sub generate_radiusd_ldap {
             $searchattributes .= '('.$searchattribute.'=%{User-Name})('.$searchattribute.'=%{Stripped-User-Name})';
         }
         $ldap_config = $TRUE;
+        my $server_list;
+        my @ldap_server = split(',',$ConfigAuthenticationLdap{$ldap}->{host});
+        foreach my $ldap_server (@ldap_server) {
+            $server_list .= "    server          = $ldap_server\n";
+        }
+        my $append = '';
+        if (defined($ConfigAuthenticationLdap{$ldap}->{append_to_searchattributes})) {
+            $append = $ConfigAuthenticationLdap{$ldap}->{append_to_searchattributes};
+        }
         $tags{'servers'} .= <<"EOT";
 
 ldap $ldap {
-    server          = "$ConfigAuthenticationLdap{$ldap}->{host}"
+$server_list
     port            = "$ConfigAuthenticationLdap{$ldap}->{port}"
     identity        = "$ConfigAuthenticationLdap{$ldap}->{binddn}"
-    password        = $ConfigAuthenticationLdap{$ldap}->{password}
+    password        = "$ConfigAuthenticationLdap{$ldap}->{password}"
     base_dn         = "$ConfigAuthenticationLdap{$ldap}->{basedn}"
     filter          = "(userPrincipalName=%{User-Name})"
-    scope           = $ConfigAuthenticationLdap{$ldap}->{scope}
+    scope           = "$ConfigAuthenticationLdap{$ldap}->{scope}"
     base_filter     = "(objectclass=user)"
-    rebind          = yes
-    chase_referrals = yes
+    rebind          = "yes"
+    chase_referrals = "yes"
     update {
         control:AD-Samaccountname := 'sAMAccountName'
         request:PacketFence-UserNameAttribute := "$ConfigAuthenticationLdap{$ldap}->{usernameattribute}"
     }
     user {
         base_dn = "\${..base_dn}"
-        filter = "(|$searchattributes(sAMAccountName=%{%{Stripped-User-Name}:-%{User-Name}}))"
+        filter = "(&(|$searchattributes(sAMAccountName=%{%{Stripped-User-Name}:-%{User-Name}}))$append)"
     }
     options {
         chase_referrals = yes
@@ -691,10 +761,16 @@ sub generate_radiusd_proxy {
     $tags{'radius_sources'} = '';
     my @radius_sources;
 
-    foreach my $realm ( sort keys %pf::config::ConfigRealm ) {
+    foreach my $realm ( @pf::config::ConfigOrderedRealm ) {
         my $options = $pf::config::ConfigRealm{$realm}->{'options'} || '';
+        my $real_realm;
+        if (defined $pf::config::ConfigRealm{$realm}->{'regex'} && $pf::config::ConfigRealm{$realm}->{'regex'} ne '') {
+            $real_realm = "\"~".$pf::config::ConfigRealm{$realm}->{'regex'}."\"";
+        } else {
+            $real_realm = $realm;
+        }
         $tags{'config'} .= <<"EOT";
-realm $realm {
+realm $real_realm {
 $options
 EOT
         if ($pf::config::ConfigRealm{$realm}->{'radius_auth'} ) {
@@ -870,10 +946,16 @@ EOT
     parse_template( \%tags, "$conf_dir/radiusd/proxy.conf.inc", "$install_dir/raddb/proxy.conf.inc" );
 
     undef %tags;
+    my $real_realm;
 
-    foreach my $realm ( sort keys %pf::config::ConfigRealm ) {
+    foreach my $realm ( @pf::config::ConfigOrderedRealm ) {
+        if (defined $pf::config::ConfigRealm{$realm}->{'regex'} && $pf::config::ConfigRealm{$realm}->{'regex'} ne '') {
+            $real_realm = "\"".$pf::config::ConfigRealm{$realm}->{'regex'}."\"";
+        } else {
+            $real_realm = $realm;
+        }
         $tags{'config'} .= <<"EOT";
-realm $realm {
+realm $real_realm {
 nostrip
 }
 EOT
@@ -987,7 +1069,11 @@ EOT
             $tags{'local_realm'} = '';
             my @realms;
             foreach my $realm ( @{$eduroam_authentication_source[0]{'local_realm'}} ) {
-                 push (@realms, "Realm == \"$realm\"");
+                 if (defined $pf::config::ConfigRealm{$realm}->{'regex'} && $pf::config::ConfigRealm{$realm}->{'regex'} ne '') {
+                     push (@realms, "Realm =~ /$pf::config::ConfigRealm{$realm}->{'regex'}/");
+                 } else {
+                     push (@realms, "Realm == \"$realm\"");
+                 }
             }
             if (@realms) {
                 $tags{'local_realm'} .= 'if ( ';
@@ -1118,6 +1204,55 @@ sub generate_radiusd_mschap {
 
 }
 
+=head2 generate_eap_choice
+
+Generate the configuration for eap choice
+
+=cut
+
+sub generate_eap_choice {
+    my ($authorize_eap_choice, $authentication_auth_type) = @_;
+        my $if = 'if';
+        foreach my $key ( @pf::config::ConfigOrderedRealm ) {
+            next if $pf::config::ConfigRealm{$key}->{'eap'} eq 'default';
+            my $choice = $key;
+            $choice = $pf::config::ConfigRealm{$key}->{'regex'} if (defined $pf::config::ConfigRealm{$key}->{'regex'} && $pf::config::ConfigRealm{$key}->{'regex'} ne '');
+            my $eap = ( defined($pf::config::ConfigRealm{$key}->{'eap'}) && $pf::config::ConfigRealm{$key}->{'eap'} ne '') ? $pf::config::ConfigRealm{$key}->{'eap'} : 'eap';
+            $$authorize_eap_choice .= <<"EOT";
+            $if (Realm =~ /$choice/) {
+                $eap {
+                    ok = return
+                }
+            }
+EOT
+            $if = 'elsif';
+        }
+        if ($if eq 'elsif') {
+            $$authorize_eap_choice .= <<"EOT";
+            else {
+                eap {
+                    ok = return
+                }
+            }
+EOT
+        } else {
+            $$authorize_eap_choice .= <<"EOT";
+            eap {
+                ok = return
+            }
+EOT
+        }
+        foreach my $key (keys %ConfigEAP) {
+            next if $key eq 'default';
+            $$authentication_auth_type .= <<"EOT";
+        Auth-Type $key {
+            $key
+        }
+EOT
+        }
+
+}
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
