@@ -19,6 +19,7 @@ use warnings;
 no warnings 'portable';
 
 use Cwd;
+use Number::Range;
 use File::Basename;
 use POSIX::2008;
 use Net::MAC::Vendor;
@@ -106,6 +107,9 @@ BEGIN {
         mac2dec
         expand_ordered_array
         make_node_id split_node_id
+        os_detection
+        random_from_range
+        extract
     );
 }
 
@@ -1650,6 +1654,52 @@ sub split_node_id {
     return ($tenant_id, $mac);
 }
 
+=item os_detection -  check the os system
+
+=cut
+
+sub os_detection {
+    my $logger = get_logger();
+    if (-e '/etc/debian_version') {
+        return "debian";
+    }elsif (-e '/etc/redhat-release') {
+        return "rhel";
+    }
+}
+
+=head2 random_from_range
+
+return random int in a range
+
+=cut
+
+sub random_from_range {
+    my ($value) = @_;
+    my $range = Number::Range->new($value);
+    my $count = $range->size;
+    my @array = $range->range;
+    return $array[rand($count)];
+}
+
+=head2 extract
+
+extract
+
+=cut
+
+sub extract {
+    my ($str, $match, $template, $default) = @_;
+    if ($str =~ /$match/) {
+        my @start = @-;
+        my @end = @+;
+        my $out = $template;
+        $out =~ s/(\$(\d+))/substr($str, $start[$2], $end[$2] - $start[$2])/ge;
+        return $out;
+    }
+
+    return $default;
+}
+
 =back
 
 =head1 AUTHOR
